@@ -1,13 +1,11 @@
 from django.contrib.auth import authenticate
-from django.conf import settings
 from rest_framework import serializers
 
 from rest_framework_jwt.settings import api_settings
-from rest_framework_jwt import jwt
 
 
-jwt_payload_handler = api_settings.DEFAULT_JWT_PAYLOAD_HANDLER
-jwt_encode_handler = api_settings.DEFAULT_JWT_ENCODE_HANDLER
+jwt_payload_handler = api_settings.JWT_PAYLOAD_HANDLER
+jwt_encode_handler = api_settings.JWT_ENCODE_HANDLER
 
 
 class JSONWebTokenSerializer(serializers.Serializer):
